Universal Cell Embedding
=================

.. include:: ./model_cards/uce.md
   :parser: myst_parser.sphinx_


.. currentmodule:: helical.models.uce
.. automodule:: helical.models.uce
.. autosummary::
   :toctree: _autosummary

   UCE
   UCEConfig
   UCE.process_data
   UCE.get_embeddings

